/* The capitalized names below (example FLASH) are the names of summary functions/procedures used in loop().
   FLASH() contains 8 procedures with delay between each function. If the functions works as a pair, flashLeft... and flashRight..., then a short
   delay is added between them. Once the pair is complete, a longer delay is added so that it is clear the next procedure is not part of the previous two.
   Example: flashMatrices follows ...Left... and ...Right... after a 500ms delay.

*/
void ALL() {

  // FLASH()                        /* 8 */
  flashRandom();      delay(slow);  // Randomly flash both matrices with random colours.
  flashLeftMatrix();  delay(slow);  // Flash all left matrix LEDs in one colour, then cycle thru colours.
  flashRightMatrix(); delay(slow);  // Flash all right matrix LEDs in one colour, then cycle thru colours.
  flashMatrices();    delay(slow);  // Flash both matrices simultaneously and cycle thru colours.
  lightRowsOf8();     delay(slow);  // Sequentially light each LED in a horizontal row then hop to next row of 8 LEDs.
  lightColumnsOf8();  delay(slow);  // Sequentially light each LED in a vertical column then hop to next column of 8 LEDs.
  flashRowsOf8();     delay(slow);  // Sequentially flash each LED in a horizontal row then hop to the right to the next row.
  flashColumnsOf8();  delay(slow);  // Sequentially flash each LED in a vertical column then hop to the right to the next column.

  // MARCH()                            /* 10: 18 */
  marchOddLRL();    delay(normal);      // March the odd-numbered LEDs back and forth, starting with the first.
  marchEvenLRL();   delay(verySlow);    // March the even-numbered LEDs back and forth, starting with the second.
  marchLR();        delay(0);           // Left-Right March. Briefly display each LED sequentially.
  marchRL();        delay(verySlow);    // Right-Left March. Briefly display each LED sequentially.
  marchOuter2Center(); delay(normal);   // Sequentially light each LED from outer to inner (0 to 4, 8 to 4 simultaneously).
  marchCenter2Outer(); delay(verySlow); // Sequentially light each LED from inner to outer (4 to 0, 4 to 8 simultaneously).
  fillO2C();        delay(normal);      // Sequentially light (one colour) from outer to inner (0 to 4, 8 to 4) but do not extinquish previous one.
  fillC2O();        delay(verySlow);    // Sequentially light (one colour) from inner to outer (4 to 0, 4 to 8) but do not extinquish previous one.
  marchClmnsL2R();  delay(normal);      // Sequentially light each column of LEDs left to right while extinguishing the previous column.
  marchClmnsR2L();  delay(verySlow);    // Sequentially light each column of LEDs right to left while extinguishing the previous column.

  // SHAPES()                           /* 19: 37 */
//  diamond(); delay(normal);             // Form a diamond shape in each matrix.
//  diamondFill(); delay(normal);         // Fill a diamond shape in each matrix.
//  diamondTopBottom(); delay(verySlow);  // Fill the top half of a diamond, followed by the bottom half of a diamond in each matrix.
//  boxCWo2i(); delay(normal);            // Display all four boxes, clockwise, outer-to-inner then inner-to-outer, on both matrices.
//  boxCWi2o(); delay(verySlow);
//  boxCCWo2i(); delay(normal);           // Display all four boxes, counter-clockwise, outer-to-inner then inner-to-outer, on both matrices.
//  boxCCWi2o(); delay(verySlow);
//  circleFill(); delay(verySlow);        // In both matrices, display each LED of a circle sequentially, then fill the circle. 
//  blockLRTBM12(); delay(verySlow);      // Display and extinguish (D&E) each matrix's horizontal quadrant (4x4) of LEDs, L to R, T to Bottom, on both matrices.
//  blockMarchLRTBM12(); delay(normal);   // D&E a 4x4 block of LEDS advancing L to R, T to B on both matrices.
//  blockLRM1M2(); delay(verySlow);       // D&E a 4x4 block of LEDS advancing across the left then the right matrix, then T to B.
//  blockTBLRM12(); delay(verySlow);      // D&E a 4x4 block of LEDS, T to B then L to R, on both matrices.
//  blockMarchTBLRM12(); delay(verySlow); // D&E a 4x4 block of LEDS advancing T to B and L to R on both matrices.
//  blockTBM1M2(); delay(verySlow);       // D&E a 4x4 block of LEDS T to B and L to R on the left matrix then the right matrix.  
//  rowWaveT2B2T(); delay(verySlow);      // D&E a row of LEDS from top to bottom to top.
//  boxes4O2I2O(); delay(500);            // D&E 4 boxes, Outer to Inner to Outer.
  diamonds6(); delay(500);              // Sequentially display 6 diamond shapes, blank all, D&E all 6.
  tictactoe(); delay(500);              // D&E tictactoe board on M12, then TL2BR objects on M1, then BL2TR objects on M2.
  gridSpots(); delay(500);              // Draw a grid then D&E spots within the grid.
  
  // WAVES()                                /* 12: 49 */
  wave16ClmnsL2R();        delay(normal);   // D&E each of 16 columns, L to R.
  wave16ClmnsR2L();        delay(verySlow); // D&E each of 16 columns, R to L.
  wave8ClmnsM12L2R();      delay(normal);   // D&E each of each matrix's 8 columns, L to R.
  wave8ClmnsM12R2L();      delay(verySlow); // D&E each of each matrix's 8 columns, R to L.
  waveHOuter2CenterM12();  delay(normal);   // On both matrices, display each row starting at top and bottom simultaneously, meeting in the middle.
  waveHCenter2OuterM12();  delay(verySlow); // The opposite of waveOuter2Center, starting in the middle and finish at the top and bottom simultaneously.
  waveHOuter2CenterM1M2(); delay(normal);   // D&E center to outer matrix1 then matrix2.
  waveHOuter2CenterM2M1(); delay(verySlow); // D&E center to outer matrix2 then matrix1.
  waveVOuter2CenterM12();  delay(normal);   // D&E vertical, outer to center, both matrices.
  waveVCenter2OuterM12();  delay(verySlow); // D&E vertical, center to outer, both matrices.
  waveDiagUL2LR2UL();      delay(normal);   // D&E diagonal, upper left to lower right to upper left, each matrix then both matrices.
  waveDiagUR2LL2UR();      delay(verySlow); // D&E diagonal, upper right to lower left to upper right, each matrix then both matrices.
  
  // DICE()                               /* 3: 52 */
  countDiceForward();   delay(normal);    // Increment both dice faces simultaneously, starting with the number 1.
  countDiceBackward();  delay(verySlow);  // Decrement both dice faces simultaneously, starting with the number 6.
  randomDice();         delay(verySlow);  // Display random number, 1 to 6, on each die.
}
