//------------------// //------------------// //------------------// //------------------// //------------------// //------------------// //------------------//
void FLASH() {
  flashRandom();      delay(slow);  // Randomly flash both matrices with random colours.
  flashLeftMatrix();  delay(slow);  // Flash all left matrix LEDs in one colour, then cycle thru colours.
  flashRightMatrix(); delay(slow);  // Flash all right matrix LEDs in one colour, then cycle thru colours.
  flashMatrices();    delay(slow);  // Flash both matrices simultaneously and cycle thru colours.
  lightRowsOf8();     delay(slow);  // Sequentially light each horizontal LED then hop to next row of 8 LEDs.
  lightColumnsOf8();  delay(slow);  // Sequentially light each vertical LED then hop to next column of 8 LEDs.
  flashRowsOf8();     delay(slow);  // Flash each LED in a horizontal row then hop to the right to the next row.
  flashColumnsOf8();  delay(slow);  // Flash each LED in a vertical column then hop to the right to the next column.
}
//------------------// //------------------// //------------------// //------------------// //------------------// //------------------// //------------------//
void flashRandom() {                  // Randomly flash both matrices of LEDs with random colours.
  matrix1.setBrightness(255);      // 0-255. 127 = half-brightness. 64 = quarter-brightness.
  matrix2.setBrightness(255);
  long currentTime = millis();        // Get current time in milliseconds.
  for (int i = 0; i < 125; i++) {     // 76. Set the display time interval to 2.0s (125 / 5ms delay).
    int randNumber1 = random(0, 64);  // random(min, max - 1). 3x3x2 = 18 LEDs.
    int randNumber2 = random(0, 64);
    int rndClr  = random(0, 24);  // Colour palette contains BLACK at position 24. (max - 1).
    matrix1.drawPixel(randNumber1, 0, aC[rndClr]); // drawPixel(x,y,colour).
    matrix2.drawPixel(randNumber2, 0, aC[rndClr]);
    matrix1.show();
    matrix2.show();
    delay(5);                         // Was 25ms.
    blankMatrices();
  }
  matrix1.setBrightness(64);  matrix2.setBrightness(64);

  // Display the elapsed time that LEDs have been blinking.
  // millis: https://www.arduino.cc/reference/en/language/functions/time/millis/
  long elapsedTime = millis() - currentTime;
  Serial.print("elapsedTime: "); Serial.println(elapsedTime);
}
//------------------//
void flashLeftMatrix() {          // Flash all left matrix LEDs in one colour, then cycle thru colours.
  matrix1.setBrightness(64);  matrix2.setBrightness(64);
  for (i = 0; i < 24; i++) {
    matrix1.fillScreen(aC[i]);    // Fill all LEDs with the same colour.
    matrix1.show();               // Any LED change requires this statement to display the change immediately.
    delay(normal);                // Delay between each change of colour filling all the Neopixels.
  }
  blankMatrices();
}
//------------------//
void flashRightMatrix() {         // Flash all right matrix LEDs in one colour, then cycle thru colours.
  matrix1.setBrightness(64);  matrix2.setBrightness(64);
  for (i = 0; i < 24; i++) {
    matrix2.fillScreen(aC[i]);
    matrix2.show();
    delay(normal);
  }
  blankMatrices();
}
//------------------//
void flashMatrices() {            // Flash both matrices simultaneously and cycle thru colours.
  matrix1.setBrightness(64);  matrix2.setBrightness(64);
  for (i = 0; i < 24; i++) {
    matrix1.fillScreen(aC[i]);
    matrix2.fillScreen(aC[i]);
    matrix1.show();
    matrix2.show();
    delay(normal);
  }
  blankMatrices();
}
//------------------//
void lightRowsOf8() {                                 // Sequentially light each horizontal row of LEDs then hop to the right to the next row.
  matrix1.setBrightness(64);  matrix2.setBrightness(64);
  for (j = 0; j < 8; j++) {                           // Go thru the first 8 colours *and* increment to each new row.
    for (int i = 0; i < 8; i++)    {                  // Each row of 8 LEDs.
      matrix1.drawPixel(i + (j * 8), 0, aC[j + 8]);
      matrix2.drawPixel(i + (j * 8), 0, aC[j + 8]);   // Incremental value is a new row: 0 + 8, 0 + 16, etc.
      matrix1.show();
      matrix2.show();
      delay(10);
    }
  } blankMatrices();
}
//------------------//
void lightColumnsOf8() {                              // Sequentially light each vertical column of LEDs then hop to the right to the next column.
  matrix1.setBrightness(64);  matrix2.setBrightness(64);
  for (j = 0; j < 8; j++) {
    for (int i = 0; i < 64; i = i + 8)    {
      matrix1.drawPixel(i + (j * 1) , 0, aC[j + 8]);
      matrix2.drawPixel(i + (j * 1) , 0, aC[j + 8]);
      matrix1.show();
      matrix2.show();
      delay(10);
    }
  } blankMatrices();
}
//------------------//
void flashRowsOf8() {                                 // Flash each LED in a horizontal row then hop to the right to the next row.
  matrix1.setBrightness(64);  matrix2.setBrightness(64);
  for (j = 0; j < 8; j++) {                           // Go thru the first 8 colours *and* increment to each new row.
    for (int i = 0; i < 8; i++)    {                  // Each row of 8 LEDs.
      matrix1.drawPixel(i + (j * 8), 0, aC[j + 8]);
      matrix2.drawPixel(i + (j * 8), 0, aC[j + 8]);   // Incremental value is a new row: 0 + 8, 0 + 16, etc.
      matrix1.show();
      matrix2.show();
      delay(15);
      matrix1.drawPixel(i + (j * 8), 0, aC[24]);      // Blank each horizontal LED.
      matrix2.drawPixel(i + (j * 8), 0, aC[24]);
      matrix1.show();
      matrix2.show();
      delay(0);
    }
  } blankMatrices();
}
//------------------//
void flashColumnsOf8() {                              // Flash each LED in a vertical column then hop to the right to the next column.
  matrix1.setBrightness(64);  matrix2.setBrightness(64);
  for (j = 0; j < 8; j++) {
    for (int i = 0; i < 64; i = i + 8)    {
      matrix1.drawPixel(i + (j * 1) , 0, aC[j + 8]);  // Incremental value is a new column: 8 + 0, 16 + 0, etc.
      matrix2.drawPixel(i + (j * 1) , 0, aC[j + 8]);
      matrix1.show();
      matrix2.show();
      delay(15);
      matrix1.drawPixel(i + (j * 1), 0, aC[24]);      // Blank each verical LED.
      matrix2.drawPixel(i + (j * 1), 0, aC[24]);
      matrix1.show();
      matrix2.show();
      delay(5);
    }
  } blankMatrices();
}
//------------------// //------------------// //------------------// //------------------// //------------------// //------------------// //------------------//
