/* __QTPY_NeoMatrix_8x8x2__52.ino by Don Prefontaine 2022-08-23.
    Parts:
    - two 8 x 8 matrices of Neopixel RGB LEDs
    - speaker/buzzer
    - blue LED & resistor
    - 3v3 Adafruit QT-PY SAMD21 microcontroller
    - QT-PY Arduino Name pins: A0,A1,A2,A3,SDA,SCL,A6. A7,A8,A9,A10,3v3,GND,5v.
*/
#define BLACK         0x0000
#define NAVY          0x000F
#define BLUE          0x001F
#define DarkGREEN     0x03E0
#define DarkCYAN      0x03EF
#define GREEN         0x07E0
#define CYAN          0x07FF
#define TURQUOISE     0x0F1B
#define DarkBLUE      0x298B
#define VeryDarkGREEN 0x3446
#define DarkTURQUOISE 0x3491
#define DarkGREY      0x39C7
#define LIME2         0x5FE0
#define DarkMAGENTA   0x612F
#define SKY           0x667F
#define MAROON        0x7800
#define PURPLE        0x780F
#define OLIVE         0x7BE0
#define DARKGREY      0x7BEF
#define DarkYELLOW    0x83E5
#define VIOLET        0x8888
#define DarkRED       0x8986
#define BROWN         0xA145
#define DarkPINK      0xA1EF
#define DarkORANGE    0xA347
#define GREENYELLOW   0xAFE5
#define LIGHTGREY     0xC618  // SILVER
#define GREY          0xE73C
#define RED           0xF800
#define MAGENTA       0xF81F
#define SALMON        0xFB2C
#define ORANGE        0xFD20
#define GOLD          0xFEA0
#define YELLOW        0xFFE0
#define WHITE         0xFFFF

#include <Adafruit_GFX.h>       // Graphics library for all displays and LEDs.
#include <Adafruit_NeoPixel.h>  // For NeoPixels and strands.
#include <Adafruit_NeoMatrix.h> // For matrices of NeoPixels.

int RGB_L = 7;       // QT-PY A7. Left 8 x 8 RGB neopixel matrix output pin. These LEDs need 5v power and 5v signal. QT-PY is 3v3.
int RGB_R = 2;       // QT-PY A2. Right 8 x 8 RGB neopixel matrix output pin.
int goButton = 6;    // QT-PY A6. Push-button input pin.
int blueLED = 1;     // QT-PY A1. Blue LED.
int speakerPin = 3;  // QT-PY A3. Buzzer output pin.

static int ledCnt = 64;   // Number of Neopixel LEDs (8 rows of 8) per matrix.
int ledCntTMP = ledCnt;   // Working copy of LED count.
int LEDstate = 0;         // Blue LED is off by default.

int buttonPRESS = 0;      // Button press is used to step through LED action choices.
int buttonStateOLD = 1;   // Push button is pulled high by default.
int buttonStateNEW = 1;   // When button is pushed, the signal is pulled low from 1 to 0.

int tooFast = 10;
int veryFast = 25;        // mS time between displaying each LED.
int fast = 50;            // Debounce time.
int normal = 100;
int slow = 250;           // Used between similar routines.
int verySlow = 500;       // Used between dissimilar routines.

/* Separate objects, matrix1 and matrix2, are setup for each 8x8 RGB LED matrix. */
// W,H,Pin, First Pixel Position, Rows or Columns, Progressive or Zigzag, GRB or RGB or RGBW, protocol speed.
// Width:8. Height:8. FPP: 0,0 (TOP LEFT). R/C: ROWS. P/ZZ: PROGRESSIVE. LED Type: GRB. Protocol Speed: 800KHz.
// Multiple matrices can be setup. Our first matrix is named matrix1.
Adafruit_NeoMatrix  matrix1 = Adafruit_NeoMatrix(ledCnt, 1, RGB_L,
                              NEO_MATRIX_TOP  + NEO_MATRIX_LEFT +
                              NEO_MATRIX_ROWS + NEO_MATRIX_PROGRESSIVE,
                              NEO_GRB         + NEO_KHZ800);                        // GRB not RGB!

Adafruit_NeoMatrix  matrix2 = Adafruit_NeoMatrix(ledCnt, 1, RGB_R,
                              NEO_MATRIX_TOP  + NEO_MATRIX_LEFT +
                              NEO_MATRIX_ROWS + NEO_MATRIX_PROGRESSIVE,
                              NEO_GRB         + NEO_KHZ800);
// Colour #defines can also be found in file Colours.ino
/* aC = arrayColours [0 to 24]. NAVY = 0 and BLACK = 24. */
int aC[25] = {NAVY, BLUE, DarkGREEN, DarkCYAN, GREEN, CYAN, TURQUOISE, DarkBLUE, VeryDarkGREEN, DarkTURQUOISE, DarkGREY, LIME2, DarkMAGENTA, SKY, MAROON, PURPLE, OLIVE, DarkGREY, DarkYELLOW, VIOLET, DarkRED, BROWN, DarkPINK, DarkORANGE, BLACK};
int i, j, k, L, M, N = 0; // Init counters.
int choices = 5;  // Switch/Case choices count.
int currentColour = aC[24];
//*******************************************************************************************//
void setup() {
  randomSeed(analogRead(A0));      // Seeds the random generator with input from the unused A0 analog pin.
  pinMode(speakerPin, OUTPUT);
  pinMode(blueLED, OUTPUT);        // Output pin for Neopixel signal.
  pinMode(goButton, INPUT_PULLUP); // SAMD (QT-PY) input push button.
  //pinMode(goButton, INPUT);      // AVR input push button if used with Arduino Uno or Nano instead of Adafruit QT-PY.
  Serial.begin(9600);              // Serial monitor for troubleshooting.
  matrix1.begin();                 // Initialize the LEFT matrix library.
  matrix2.begin();                 // Initialize the RIGHT matrix library.
  matrix1.setBrightness(100);      // 0-255. 127 = half-brightness.
  matrix2.setBrightness(100);
  blankMatrices(); delay(1000);    // Ensure matrix is blank (colour Black) before starting loop.
}                                  // Displaying the colour Black has the same effect as blanking the LED.
//*******************************************************************************************//
void loop() {                      // Execute routines with LED matrices briefly blanking between each procedure.
  //ALL();                         // These functions are normally called up by pressing the Go button.
  // For testing purposes they are executed repeatedly here.

  ALL();

  delay(1000);
  /*
    buttonStateNEW = digitalRead(goButton);  // Read the push-button.
    if (buttonStateNEW != buttonStateOLD) {
      if (buttonStateNEW == LOW) {           // Go button was pressed (pulled low).
        buttonPRESS++;                       // Increment the button press counter. (k = k + 1 or k += 1 or k++;)
        Serial.print("buttonPRESS: "); Serial.println(buttonPRESS);
      }
      switch (buttonPRESS) {        // Each successive button press causes the next Case statement to execute.
        case 1:
          if (buttonPRESS == 1) {   // Go button was pressed once.
            start();                // Light the blue LED briefly and beep the buzzer high.
            delay(500);
            beepCLIK();             // Emulates the sound of a keyclick.
            FLASH();
          }
          break;
        case 2:
          if (buttonPRESS == 2) {   // Button was pressed a second time.
            beepCLIK();
            MARCH();
          }
          break;
        case 3:
          if (buttonPRESS == 3) {   // Third press.
            beepCLIK();
            SHAPES();
          }
          break;

        case 4:
          if (buttonPRESS == 4) {   // Fifth press.
            beepCLIK();
            WAVES();
            WAVES();
          }
          break;
        case 5:                     // Fourth press.
          if (buttonPRESS == 5) {
            beepCLIK();
            DICE();
          }
          break;
        case 6:
          if (buttonPRESS == 6) {   // Sixth press.
            finish();               // Light the LED briefly and beep the buzzer low.
          }
          break;
        default:                    // No default action. Wrap the switch procedure to the beginning.
          // No default action.
          break;
      }
    }
  */
}
//------------------//
void start() {
  digitalWrite(blueLED, HIGH);    // Light the LED briefly and beep the buzzer high for 2 seconds.
  beepHIGH();
  digitalWrite(blueLED, LOW);
}
//------------------//
void finish() {
  digitalWrite(blueLED, HIGH);    // Light the LED briefly and beep the buzzer low for 1 second.
  beepLOW();
  buttonPRESS = 0;
  //Serial.println("Resetting button presses count to 0.\n");
  digitalWrite(blueLED, LOW);
}
//------------------//

//***********************************************************************************//
// Reference:
// const uint16_t colors[] = { matrix.Color(255, 0, 0), matrix.Color(0, 255, 0), matrix.Color(0, 0, 255) };

/* https://learn.adafruit.com/adafruit-neopixel-uberguide
    Page 59 of 105: Arduino Library use of strip.setPixel()
    Page 71 of 105: NeoMatrix Library using matrix command.

    void drawPixel(int16_t x, int16_t y, uint16_t color);
    void fillScreen(uint16_t color);

*/
